@@ -1,7 +1,9 @@
 from dataclasses import dataclass
-from typing import Optional
-from enum import Enum
+from typing import Optional, List
 from annotell.input_api.model.abstract.abstract_models import Response
+from datetime import datetime
+from enum import Enum
+from annotell.input_api.util import ts_to_dt
 
 
 class InputStatus(str, Enum):
@@ -21,17 +23,21 @@ class Input(Response):
     batch: str
     input_type: str
     status: InputStatus
+    created: datetime
+    calibration_id: Optional[str]
     view_link: Optional[str]
     error_message: Optional[str]
 
     @staticmethod
     def from_json(js: dict):
         return Input(
-            js["internalId"],
-            js["externalId"],
-            js["batchId"],
-            js["inputType"],
-            js["status"],
-            js.get("viewLink"),
-            js.get("errorMessage")
+            uuid=js["internalId"],
+            external_id=js["externalId"],
+            batch=js["batchId"],
+            input_type=js["inputType"],
+            status=js["status"],
+            created=ts_to_dt(js["created"]),
+            view_link=js.get("viewLink"),
+            calibration_id=js.get("calibrationId"),
+            error_message=js.get("errorMessage")
         )
